Skip site navigation (1)Skip section navigation (2)
Date:      Mon, 21 May 2012 22:39:14 +0000 (UTC)
From:      Adrian Chadd <adrian@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-head@freebsd.org
Subject:   svn commit: r235749 - head/sys/dev/ath
Message-ID:  <201205212239.q4LMdEPa076731@svn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: adrian
Date: Mon May 21 22:39:13 2012
New Revision: 235749
URL: http://svn.freebsd.org/changeset/base/235749

Log:
  Rename ath_tx_cleanup() -> ath_tx_tid_cleanup() in order to not clash
  with a symbol in if_ath.c

Modified:
  head/sys/dev/ath/if_ath_tx.c

Modified: head/sys/dev/ath/if_ath_tx.c
==============================================================================
--- head/sys/dev/ath/if_ath_tx.c	Mon May 21 22:23:21 2012	(r235748)
+++ head/sys/dev/ath/if_ath_tx.c	Mon May 21 22:39:13 2012	(r235749)
@@ -3094,7 +3094,7 @@ ath_tx_comp_cleanup_unaggr(struct ath_so
  * The caller is responsible for pausing the TID.
  */
 static void
-ath_tx_cleanup(struct ath_softc *sc, struct ath_node *an, int tid)
+ath_tx_tid_cleanup(struct ath_softc *sc, struct ath_node *an, int tid)
 {
 	struct ath_tid *atid = &an->an_tid[tid];
 	struct ieee80211_tx_ampdu *tap;
@@ -4419,11 +4419,11 @@ ath_addba_stop(struct ieee80211_node *ni
 	sc->sc_addba_stop(ni, tap);
 
 	/*
 	 * ath_tx_cleanup will resume the TID if possible, otherwise
 	 * it'll set the cleanup flag, and it'll be unpaused once
 	 * things have been cleaned up.
 	 */
-	ath_tx_cleanup(sc, an, tid);
+	ath_tx_tid_cleanup(sc, an, tid);
 }
 
 /*
@@ -4419,11 +4419,11 @@ ath_addba_stop(struct ieee80211_node *ni
 
 	/*
-	 * ath_tx_cleanup will resume the TID if possible, otherwise
+	 * ath_tx_tid_cleanup will resume the TID if possible, otherwise
 	 * it'll set the cleanup flag, and it'll be unpaused once
 	 * things have been cleaned up.



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201205212239.q4LMdEPa076731>